@@ -4,15 +4,21 @@ kombu.compression
 
 Compression utilities.
 
-:copyright: (c) 2009 - 2010 by Ask Solem.
+:copyright: (c) 2009 - 2012 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
+from __future__ import absolute_import
+
+import zlib
 
 _aliases = {}
 _encoders = {}
 _decoders = {}
 
+__all__ = ["register", "encoders", "get_encoder",
+           "get_decoder", "compress", "decompress"]
+
 
 def register(encoder, decoder, content_type, aliases=[]):
     """Register new compression method.
@@ -52,7 +58,7 @@ def compress(body, content_type):
 
     """
     encoder, content_type = get_encoder(content_type)
-    return encoder(body), content_type
+    return encoder(body.encode("utf-8")), content_type
 
 
 def decompress(body, content_type):
@@ -62,12 +68,17 @@ def decompress(body, content_type):
     :param content_type: mime-type of compression method used.
 
     """
-    return get_decoder(content_type)(body)
+    return get_decoder(content_type)(body).decode("utf-8")
 
 
-register(lambda x: x.encode("zlib"),
-         lambda x: x.decode("zlib"),
+register(zlib.compress,
+         zlib.decompress,
          "application/x-gzip", aliases=["gzip", "zlib"])
-register(lambda x: x.encode("bz2"),
-         lambda x: x.decode("bz2"),
-         "application/x-bz2", aliases=["bzip2", "bzip"])
+try:
+    import bz2
+except ImportError:
+    pass  # Jython?
+else:
+    register(bz2.compress,
+             bz2.decompress,
+             "application/x-bz2", aliases=["bzip2", "bzip"])
