@@ -4,16 +4,18 @@ kombu.transport.SQS
 
 Amazon SQS transport.
 
-:copyright: (c) 2010 - 2011 by Ask Solem
+:copyright: (c) 2010 - 2012 by Ask Solem
 :license: BSD, see LICENSE for more details.
 
 """
+from __future__ import absolute_import
+
 import socket
 import string
 
 from Queue import Empty
 
-from anyjson import serialize, deserialize
+from anyjson import loads, dumps
 
 from boto import exception
 from boto import sdb as _sdb
@@ -23,10 +25,10 @@ from boto.sdb.connection import SDBConnection
 from boto.sqs.connection import SQSConnection
 from boto.sqs.message import Message
 
-from kombu.transport import virtual
-from kombu.utils import cached_property, uuid
-from kombu.utils.encoding import safe_str
+from ..utils import cached_property, uuid
+from ..utils.encoding import safe_str
 
+from . import virtual
 
 # dots are replaced by dash, all other punctuation
 # replaced by underscore.
@@ -156,6 +158,7 @@ class Channel(virtual.Channel):
 
     def _new_queue(self, queue, **kwargs):
         """Ensures a queue exists in SQS."""
+        queue = self.queue_name_prefix + queue
         try:
             return self._queue_cache[queue]
         except KeyError:
@@ -211,7 +214,7 @@ class Channel(virtual.Channel):
         """Put message onto queue."""
         q = self._new_queue(queue)
         m = Message()
-        m.set_body(serialize(message))
+        m.set_body(dumps(message))
         q.write(m)
 
     def _put_fanout(self, exchange, message, **kwargs):
@@ -225,7 +228,7 @@ class Channel(virtual.Channel):
         rs = q.get_messages(1)
         if rs:
             m = rs[0]
-            payload = deserialize(rs[0].get_body())
+            payload = loads(rs[0].get_body())
             if queue in self._noack_queues:
                 q.delete_message(m)
             else:
@@ -321,6 +324,10 @@ class Channel(virtual.Channel):
     def visibility_timeout(self):
         return self.transport_options.get("visibility_timeout")
 
+    @cached_property
+    def queue_name_prefix(self):
+        return self.transport_options.get("queue_name_prefix", '')
+
     @cached_property
     def supports_fanout(self):
         return self.transport_options.get("sdb_persistence", False)
