@@ -37,6 +37,14 @@ transport.AMQP_PROTOCOL_HEADER = str_to_bytes("AMQP\x01\x01\x08\x00")
 
 class Connection(amqp.Connection):  # pragma: no cover
 
+    def _do_close(self, *args, **kwargs):
+        # amqplib does not ignore socket errors when connection
+        # is closed on the remote end.
+        try:
+            super(Connection, self)._do_close(*args, **kwargs)
+        except socket.error:
+            pass
+
     def _dispatch_basic_return(self, channel, args, msg):
         reply_code = args.read_short()
         reply_text = args.read_shortstr()
@@ -250,8 +258,22 @@ class Transport(base.Transport):
         connection.client = None
         connection.close()
 
+    def is_alive(self, connection):
+        sock = connection.transport.sock
+        prev = sock.gettimeout()
+        sock.settimeout(0.0001)
+        try:
+            sock.recv(1, socket.MSG_PEEK)
+        except socket.timeout:
+            pass
+        except socket.error:
+            return False
+        finally:
+            sock.settimeout(prev)
+        return True
+
     def verify_connection(self, connection):
-        return connection.channels is not None
+        return connection.channels is not None and self.is_alive(connection)
 
     @property
     def default_connection_params(self):
