@@ -4,14 +4,15 @@ kombu.transport.base
 
 Base transport interface.
 
-:copyright: (c) 2009 - 2011 by Ask Solem.
+:copyright: (c) 2009 - 2012 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
+from __future__ import absolute_import
 
-from kombu import serialization
-from kombu.compression import decompress
-from kombu.exceptions import MessageStateError
+from ..serialization import decode
+from ..compression import decompress
+from ..exceptions import MessageStateError
 
 ACKNOWLEDGED_STATES = frozenset(["ACK", "REJECTED", "REQUEUED"])
 
@@ -20,11 +21,11 @@ class StdChannel(object):
     no_ack_consumers = None
 
     def Consumer(self, *args, **kwargs):
-        from kombu.messaging import Consumer
+        from ..messaging import Consumer
         return Consumer(self, *args, **kwargs)
 
     def Producer(self, *args, **kwargs):
-        from kombu.messaging import Producer
+        from ..messaging import Producer
         return Producer(self, *args, **kwargs)
 
     def list_bindings(self):
@@ -36,43 +37,28 @@ class StdChannel(object):
            after transient reply message received."""
         pass
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *exc_info):
+        self.close()
+
 
 class Message(object):
     """Base class for received messages."""
-    _state = None
-
+    __slots__ = ("_state", "channel", "delivery_tag",
+                 "content_type", "content_encoding",
+                 "delivery_info", "headers",
+                 "properties", "body",
+                 "_decoded_cache",
+                 "MessageStateError", "__dict__")
     MessageStateError = MessageStateError
 
-    #: The channel the message was received on.
-    channel = None
-
-    #: Delivery tag used to identify the message in this channel.
-    delivery_tag = None
-
-    #: Content type used to identify the type of content.
-    content_type = None
-
-    #: Content encoding used to identify the text encoding of the body.
-    content_encoding = None
-
-    #: Additional delivery information.
-    delivery_info = None
-
-    #: Message headers
-    headers = None
-
-    #: Application properties
-    properties = None
-
-    #: Raw message body (may be serialized), see :attr:`payload` instead.
-    body = None
-
     def __init__(self, channel, body=None, delivery_tag=None,
             content_type=None, content_encoding=None, delivery_info={},
             properties=None, headers=None, postencode=None,
             **kwargs):
         self.channel = channel
-        self.body = body
         self.delivery_tag = delivery_tag
         self.content_type = content_type
         self.content_encoding = content_encoding
@@ -82,11 +68,13 @@ class Message(object):
         self._decoded_cache = None
         self._state = "RECEIVED"
 
-        compression = self.headers.get("compression")
-        if compression:
-            self.body = decompress(self.body, compression)
-        if postencode and isinstance(self.body, unicode):
-            self.body = self.body.encode(postencode)
+        try:
+            body = decompress(body, self.headers["compression"])
+        except KeyError:
+            pass
+        if postencode and isinstance(body, unicode):
+            body = body.encode(postencode)
+        self.body = body
 
     def ack(self):
         """Acknowledge this message as being processed.,
@@ -110,6 +98,13 @@ class Message(object):
         self.channel.basic_ack(self.delivery_tag)
         self._state = "ACK"
 
+    def ack_log_error(self, logger, errors):
+        try:
+            self.ack()
+        except errors, exc:
+            logger.critical("Couldn't ack %r, reason:%r",
+                    self.delivery_tag, exc, exc_info=True)
+
     def reject(self):
         """Reject this message.
 
@@ -144,8 +139,8 @@ class Message(object):
     def decode(self):
         """Deserialize the message body, returning the original
         python structure sent by the publisher."""
-        return serialization.decode(self.body, self.content_type,
-                                    self.content_encoding)
+        return decode(self.body, self.content_type,
+                      self.content_encoding)
 
     @property
     def acknowledged(self):
